@@ -16,10 +16,10 @@ def walk(sid, doc):
 		add( "#LEX", f"#{t.pos_}", f"#{t.tag_}",f"#{t.dep_}",) # book:VERB:VBG
 		if t.pos_ not in ("PROPN","PUNCT","SPACE") and t.is_alpha and t.head.is_alpha: #*:VERB:~punct:VERB:wink
 			reg(f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}", sid) 
-			add(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}", f"*:{t.head.pos_}:{t.dep_}")
+			add(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}",f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}", f"*:{t.head.pos_}:{t.dep_}")
 			reg(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", sid)
 			if t.dep_ not in ('ROOT'): 
-				add(f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}:{t.head.lemma_}", f"{t.lemma_}:{t.pos_}:~{t.dep_}", f"*:{t.pos_}:~{t.dep_}")
+				add(f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}:{t.head.lemma_}", f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}", f"{t.lemma_}:{t.pos_}:~{t.dep_}", f"*:{t.pos_}:~{t.dep_}")
 				reg(f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}:{t.head.lemma_}", sid)		
 			
 	for sp in doc.noun_chunks: #book:NOUN:np:a book
@@ -63,7 +63,7 @@ def mysql(dbfile, host='127.0.0.1', port=3307, cutoff=0):
 	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db='kpsi')
 	with my_conn.cursor() as cursor: 
 		cursor.execute(f"drop TABLE if exists {name}")
-		cursor.execute(f"CREATE TABLE if not exists {name}(s varchar(128) COLLATE latin1_bin not null primary key, i int not null default 0, t text not null default '') engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+		cursor.execute(f"CREATE TABLE if not exists {name}(s varchar(128) COLLATE latin1_bin not null primary key, i int not null default 0, t text) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin") # not null default ''
 		cursor.execute(f"drop TABLE if exists {name}_snt")
 		cursor.execute(f"CREATE TABLE if not exists {name}_snt(sid int primary key, snt text not null, kps text not null, fulltext key `snt`(`snt`), fulltext key `kps`(`kps`) ) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
 
