@@ -1,8 +1,6 @@
 # 2022.6.30 cp from dsk/__init__.py , NO redis 
 from uvirun import * 
-import json, requests,time,sys, traceback, difflib, en
-from dsk import score 
-from gec_fastapi import gecsnts
+import json, requests,time,sys, traceback, difflib,os, en
 
 trans_diff		= lambda src, trg:  [] if src == trg else [s for s in difflib.ndiff(src, trg) if not s.startswith('?')] #src:list, trg:list
 trans_diff_merge= lambda src, trg:  [] if src == trg else [s.strip() for s in "^".join([s for s in difflib.ndiff(src, trg) if not s.startswith('?')]).replace("^+","|+").split("^") if not s.startswith("+") ]
@@ -17,6 +15,31 @@ def mkf_input(snts, docs, tokenizer, sntdic:dict={},diffmerge:bool=False):
 				for i, doc in enumerate(docs)]
 	return input #mkfs	= requests.post(f"http://172.17.0.1:7095/parser", data={"q":json.dumps(input).encode("utf-8")}).json()
 
+# gec_redis=192.168.201.120:6379 uvicorn dsk_fastapi:app --host 0.0.0.0 --port 8080  
+gec_redis = os.getenv('gec_redis','192.168.201.120:6379') # xsnts consumer deployed 
+dsk_host  = os.getenv('dsk_host','172.17.0.1:7095')
+@app.get('/dsk/xgec', tags=["dsk"])
+def dsk_xgec(essay_or_snts:str="She has ready. It are ok.", asdsk:bool=True, timeout:int=5,): # rgec_host:str='192.168.201.120', rgec_port:int=6379 , dskhost:str='172.17.0.1:7095'
+	''' assure: rgec_host is in the white ip list, added 2022.7.19 '''
+	import redis
+	if not hasattr(dsk_xgec,'r'): dsk_xgec.r = redis.Redis(host=gec_redis.split(":")[0], port=int(gec_redis.split(":")[-1]), decode_responses=True)
+	tims	= [time.time()]
+	snts	= json.loads(essay_or_snts) if essay_or_snts.startswith('["') else sntbr(essay_or_snts)
+	id	= dsk_xgec.r.xadd("xsnts", {'snts':json.dumps(snts)})
+	res = dsk_xgec.r.blpop([f"suc:{id}",f"err:{id}"], timeout=timeout)
+	dsk_xgec.r.xdel("xsnts", id)
+	tims.append(time.time())
+	if res is None: return {"** failed xgec": essay_or_snts}
+
+	sntdic = json.loads(res[1])
+	docs	= [spacy.nlp(snt) for snt in snts ] 
+	tims.append(time.time())
+	input	= mkf_input(snts, docs, spacy.nlp.tokenizer, sntdic)
+	dsk		= requests.post(f"http://{dsk_host}/parser", data={"q":json.dumps({"snts":input, "rid":"10"} if asdsk else input).encode("utf-8")}).json()
+	tims.append(time.time())
+	dsk['tim'] = {'gec': tims[1] - tims[0] , 'parse': tims[2] - tims[1] , 'mkf': tims[3] - tims[2] }
+	return dsk
+
 @app.get('/dsk/register_redis', tags=["dsk"])
 def register_redis(rinfo:str='172.17.0.1:6379:0'):
 	''' to enable redis cache for snt parsing , 2022.6.30 '''
@@ -45,6 +68,8 @@ def post_dsk(arr:dict={'essay_or_snts':"She has ready. It are ok.", # arr from m
 				"word_gt7":[0.11, 0.19, 0.3, 0.42, 0.49,			1, 0.0588, 0.1289]}}
 		, asdsk:bool=True, debug:bool= False, dskhost:str='172.17.0.1:7095'): 
 	''' essay_or_snts:  either essay or snts, dumped by json.dumps, ' '''
+	from dsk import score 
+	from gec_fastapi import gecsnts
 	try:
 		tims	= [ ("start", time.time(), 0)] # tag, tm, delta 
 		essay_or_snts = arr.get("essay_or_snts","")
