@@ -14,6 +14,12 @@ def dualarr_keyness(src:dict={"one":2, "two":12}, tgt:dict={"three":3, "one":1},
 	res.sort(key=lambda a:a[-1], reverse=True)
 	return [ar for ar in res if abs(ar[-1]) > threshold ]
 
+@app.get('/essays')
+def dic_docs(name:str='hello'): 
+	''' src data in pypi/dic/__init__.py '''
+	import dic 
+	return dic.docs(name) 
+
 if __name__ == "__main__":  
 	print (dualarr_keyness())
 	uvicorn.run(app, host='0.0.0.0', port=80)
\ No newline at end of file
